//--------------------------------------------------------------
// Press F1 to get help about using script.
// To access an object that is not located in the current class, start the call with Globals.
// When using events and timers be cautious not to generate memoryleaks,
// please see the help for more information.
//---------------------------------------------------------------
	
    /*
	*******************************************************************
	All examples in this support document are only intended
	to improve understanding of the functionality and 
	handling of the equipment. 
	Beijer Electronics AB cannot assume any liability if these
	examples are used in real applications.
	In view of the wide range of applications for this 
	equipment, users must acquire sufficient knowledge 
	themselves in order to ensure that it is correctly used in 
	their specific application. Persons responsible for the 
	application and the equipment must themselves 
	ensure that each application is in compliance with all 
	relevant requirements, standards and legislation in 
	respect to configuration and safety.
	Beijer Electronics AB will accept no liability for any 
	damage incurred during the installation or use of this 
	equipment.
	Beijer Electronics AB prohibits all modification, changes
	or conversion of the equipment.
	*******************************************************************
	*/

namespace Neo.ApplicationFramework.Generated
{
	using System.Windows.Forms;
	using System;
	using System.Drawing;
	using Neo.ApplicationFramework.Tools;
	using Neo.ApplicationFramework.Common.Graphics.Logic;
	using Neo.ApplicationFramework.Controls;
	using Neo.ApplicationFramework.Interfaces;

	// additional libraries needed	
	using System.IO;
	using System.Reflection;
	using System.Collections.Generic;
    
    
	public partial class MailScriptModule
	{
		// Define String constants for displaying error messages or success messages.
		// This is ofcourse optional, and can be skiped if you dont need\want responds.
		private const string STR_EmailDeviceNotConfigured = "The email device is not correctly configured.\nGo to Alarm Distributor and configure it.\n\n";
		private const string STR_SMTPServerNotSpecified = "The SMTP Server is not specified!";
		private const string STR_FromNameMustBeSpecified = "The 'From name' must be specified!";
		private const string STR_FromEmailMustBeSpecified = "The 'From email' must be specified!";
		private const string STR_TheRecipientCannotBeEmpty = "The recipient cannot be empty!";
		private const string STR_YouCantSendEmptyMail = "You can't send a mail without subject and body.";
		private const string STR_NoEmailSenderService = "Could not get the EmailSenderService!";
		private const string STR_MessageSuccessfullySent = "Message successfully sent!";

			
		// Try to send an email. 
		
		// Input to this module is: ToAdress, Subject, Body, attacement 
		// in addition the email device must be configured correctly in the Alarm distribution function in IX.
		// SMTP mail is used. SSL encryption is NOT supported, thus requiring a local email server. e.g. smtp.beijer.no
		// (Public mailservers mostly require ssl encryption eg gmail,hotmail,online etc) 
	
		//<param name="toAddress"> Recipients email address.</param>;
		// <param name="subject">The subject of the message.</param>
		// <param name="body">The message body.</param>
		// <returns>Error message if anything went wrong, otherwise a success message.</returns>
		public string SendEmail(string toAddress, string subject, string body, string attachment)
		{
			// Checks if the EmailDevice is configured.
			string deviceConfigureError = IsEmailDeviceConfigured;
			
			// If there was missing data in the EmailDevice, abort and send a error message.
			if (!string.IsNullOrEmpty(deviceConfigureError))
				return STR_EmailDeviceNotConfigured + deviceConfigureError;

			// Check that the input parameters is set (To,Subject,Boddy)
			string parameterError = ValidateParameters(toAddress, subject, body);
			
			// If there was missing data, abort and send a error message.
			if (!string.IsNullOrEmpty(parameterError))
				return parameterError;
			
			// Be very careful if you decide to use this code! 
			// The IEmailSenderService is an internal service, and can change 
			// between versions of iX Developer!
			// You need to test this on the version of iX you are using
			
			IEmailSenderService MyEmailSenderService = Globals.GetService<IEmailSenderService>();
			
			// If the service was not found, abort and send an error message.
			if (MyEmailSenderService == null)
				return STR_NoEmailSenderService;
			
			// Add attachement(s)
			
			List<string> attachements = new List<string>();
			if(File.Exists(attachment))
			{
				attachements.Add(attachment);
			}
			else
			{	
				MessageBox.Show("File / filepath don't exist");
			}
			// Use the service to send the email.
			SendResult sendResult = MyEmailSenderService.SendEmail(toAddress, subject, body, attachements, null, 1);
			
			// If there was an error while trying to send, return the error message.
			if (!sendResult.SendOK)
				return sendResult.Message;

			// If everything went well, send an message sent successfully mail.
			return STR_MessageSuccessfullySent;
		}

		// Checks if the common properties of the EmailDevice is set.

		private static string IsEmailDeviceConfigured 
		{
			get
			{
				// Get the EmailDevice and hold it in a temporary variable.
				IEmailDevice MyMailDevice = Globals.EmailDevice1;
				
				// If SMTP Server Name/IP is not set, return a error message telling this.
				if (string.IsNullOrEmpty(MyMailDevice.SMTPServer))
					return STR_SMTPServerNotSpecified;

				// If From Name is not set, return a error message telling this.
				if (string.IsNullOrEmpty(MyMailDevice.FromName))
					return STR_FromNameMustBeSpecified;

				// If From Email Address is not set, return a error message telling this.
				if (string.IsNullOrEmpty(MyMailDevice.FromEmailAddress))
					return STR_FromEmailMustBeSpecified;
                
				// If the common properties was set, return a empty string.
				return string.Empty;
			}
		}
		

		// Validate the parameters to use in the email.
	
		// "toAddress" = Recipient's email address
		// "subject"   = The subject of the message
		// "body"      = The message body
		
		// <returns>Empty string if everything was ok, otherwise a error message		
		private static string ValidateParameters(string toAddress, string subject, string body)
		{
			// If recipient address was empty, return a error message for this.
			if (string.IsNullOrEmpty(toAddress))
				return STR_TheRecipientCannotBeEmpty;

			// If both subject and body was empty, return a error message for this.
			if (string.IsNullOrEmpty(subject) && string.IsNullOrEmpty(body))
				return STR_YouCantSendEmptyMail;

			// If everything was ok, send an empty string.
			return string.Empty;
		}
	}
}
